@@ -272,7 +272,7 @@ def plot2(freq,ZQS,modes, labels, freqs_from_disp):
             axs = [axs]
         for i in range(n_modes): #iterating over the modes
             mode = modes[i]
-            axs[i].plot(np.repeat(freqs_from_disp[mode,n],100),np.linspace(0,ZQS[:,0,n].max(),100),c='r', label='freq from dispersion')
+            axs[i].plot(np.repeat(freqs_from_disp[mode,n],100),np.linspace(0,ZQS[n,:,:].max(),100), c='r', label='freq from dispersion')
             axs[i].plot(freq,ZQS[n,:,0], ':', color='grey')
             axs[i].text(.75,.75,labels[n]+str('\n mode')+str(mode),fontsize=12,horizontalalignment='center', verticalalignment='center',transform=axs[i].transAxes)
             axs[i].plot(freq, ZQS[n,:,mode+1])
@@ -286,8 +286,8 @@ def plot2(freq,ZQS,modes, labels, freqs_from_disp):
         plt.xlabel('Frequency [Thz]')
 #        plt.tight_layout()
         
-    plt.show() 
-    fig.savefig('plot2.pdf')
+        plt.show() 
+        fig.savefig('plot2_'+str(n)+'.pdf')
     return
 
 
